@@ -1,7 +1,7 @@
 from qai.issues.add_issues import parse
 
 
-def get_payload_stats(json_data, nlp):
+def get_payload_stats(json_data):
     try:
         _ = json_data.items()
         els = [json_data]
@@ -9,13 +9,13 @@ def get_payload_stats(json_data, nlp):
         els = json_data
 
     n_seg = len(els) if els else 0
-    n_sent = 0
+    n_sent = -1
     n_word = 0
 
     try:
         for el in els:
             segment, _, _ = parse(el)
-            n_sent += len(list(nlp(segment).sents))
+            # n_sent += len(list(nlp(segment).sents))
             n_word += len(segment.split())
     except:
         # this will cause escaped exception in sanic logger
