@@ -244,7 +244,7 @@ class QRest(QRemoteConnection):
         # This works, but it is better to make these after instantiating the class
         # that way you don't need partial application... see README
         unary_post_root = partial(post_root, self)
-        unary_get_root = partial(v2, self)
+        unary_get_root = partial(get_root, self)
         unary_v2 = partial(v2, self)
         self.app.add_route(unary_post_root, "/", methods=["POST"])
         self.app.add_route(unary_get_root, "/", methods=["GET"])
